"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getAllConnectorsIncludingSystemRoute = void 0;
var _common = require("../../../../common");
var _verify_access_and_context = require("../../verify_access_and_context");
var _transforms = require("../get_all/transforms");
var _constants = require("../../constants");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const getAllConnectorsIncludingSystemRoute = (router, licenseState) => {
  router.get({
    path: `${_common.INTERNAL_BASE_ACTION_API_PATH}/connectors`,
    security: _constants.DEFAULT_ACTION_ROUTE_SECURITY,
    validate: {},
    options: {
      access: 'internal'
    }
  }, router.handleLegacyErrors((0, _verify_access_and_context.verifyAccessAndContext)(licenseState, async function (context, req, res) {
    const actionsClient = (await context.actions).getActionsClient();
    const result = await actionsClient.getAll({
      includeSystemActions: true
    });
    const responseBody = (0, _transforms.transformGetAllConnectorsResponseV1)(result);
    return res.ok({
      body: responseBody
    });
  })));
};
exports.getAllConnectorsIncludingSystemRoute = getAllConnectorsIncludingSystemRoute;