"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CaseViewTabs = void 0;
var _eui = require("@elastic/eui");
var _react = _interopRequireWildcard(require("react"));
var _react2 = require("@emotion/react");
var _types = require("../../../common/types");
var _navigation = require("../../common/navigation");
var _use_cases_context = require("../cases_context/use_cases_context");
var _translations = require("./translations");
var _use_get_case_file_stats = require("../../containers/use_get_case_file_stats");
var _use_case_observables = require("./use_case_observables");
var _experimental_badge = require("../experimental_badge/experimental_badge");
var _use_get_similar_cases = require("../../containers/use_get_similar_cases");
var _use_cases_features = require("../../common/use_cases_features");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const TabTitle = ({
  title
}) => /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, {
  size: "xxs"
}, /*#__PURE__*/_react.default.createElement("h2", {
  className: "eui-displayInline"
}, title));
TabTitle.displayName = 'TabTitle';
const FilesBadge = ({
  activeTab,
  fileStatsData,
  isLoading,
  euiTheme
}) => /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, !isLoading && fileStatsData && /*#__PURE__*/_react.default.createElement(_eui.EuiNotificationBadge, {
  css: (0, _react2.css)`
          margin-left: ${euiTheme.size.xs};
        `,
  "data-test-subj": "case-view-files-stats-badge",
  color: activeTab === _types.CASE_VIEW_PAGE_TABS.FILES ? 'accent' : 'subdued'
}, fileStatsData.total > 0 ? fileStatsData.total : 0));
FilesBadge.displayName = 'FilesBadge';
const ObservablesBadge = ({
  activeTab,
  isLoading,
  euiTheme,
  count
}) => /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, !isLoading && /*#__PURE__*/_react.default.createElement(_eui.EuiNotificationBadge, {
  css: (0, _react2.css)`
          margin-left: ${euiTheme.size.xs};
        `,
  "data-test-subj": "case-view-observables-stats-badge",
  color: activeTab === _types.CASE_VIEW_PAGE_TABS.OBSERVABLES ? 'accent' : 'subdued'
}, count));
ObservablesBadge.displayName = 'ObservablesBadge';
const SimilarCasesBadge = ({
  activeTab,
  count,
  euiTheme
}) => /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiNotificationBadge, {
  css: (0, _react2.css)`
          margin-left: ${euiTheme.size.xs};
        `,
  "data-test-subj": "case-view-similar-cases-badge",
  color: activeTab === _types.CASE_VIEW_PAGE_TABS.SIMILAR_CASES ? 'accent' : 'subdued'
}, count !== null && count !== void 0 ? count : 0));
SimilarCasesBadge.displayName = 'SimilarCasesBadge';
const AlertsBadge = ({
  activeTab,
  totalAlerts,
  isExperimental,
  euiTheme
}) => /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiNotificationBadge, {
  css: (0, _react2.css)`
        margin-left: ${euiTheme.size.xs};
      `,
  "data-test-subj": "case-view-alerts-stats-badge",
  color: activeTab === _types.CASE_VIEW_PAGE_TABS.ALERTS ? 'accent' : 'subdued'
}, totalAlerts || 0), isExperimental && /*#__PURE__*/_react.default.createElement(_experimental_badge.ExperimentalBadge, {
  compact: true,
  "data-test-subj": "case-view-alerts-table-experimental-badge"
}));
AlertsBadge.displayName = 'AlertsBadge';
const CaseViewTabs = exports.CaseViewTabs = /*#__PURE__*/_react.default.memo(({
  caseData,
  activeTab
}) => {
  const {
    features
  } = (0, _use_cases_context.useCasesContext)();
  const {
    navigateToCaseView
  } = (0, _navigation.useCaseViewNavigation)();
  const {
    euiTheme
  } = (0, _eui.useEuiTheme)();
  const {
    data: fileStatsData,
    isLoading: isLoadingFiles
  } = (0, _use_get_case_file_stats.useGetCaseFileStats)({
    caseId: caseData.id
  });
  const {
    observables,
    isLoading: isLoadingObservables
  } = (0, _use_case_observables.useCaseObservables)(caseData);
  const {
    observablesAuthorized: canShowObservableTabs
  } = (0, _use_cases_features.useCasesFeatures)();
  const {
    data: similarCasesData
  } = (0, _use_get_similar_cases.useGetSimilarCases)({
    caseId: caseData.id,
    perPage: 0,
    page: 0,
    enabled: canShowObservableTabs
  });
  const tabs = (0, _react.useMemo)(() => [{
    id: _types.CASE_VIEW_PAGE_TABS.ACTIVITY,
    name: _translations.ACTIVITY_TAB
  }, ...(features.alerts.enabled ? [{
    id: _types.CASE_VIEW_PAGE_TABS.ALERTS,
    name: _translations.ALERTS_TAB,
    badge: /*#__PURE__*/_react.default.createElement(AlertsBadge, {
      isExperimental: features.alerts.isExperimental,
      totalAlerts: caseData.totalAlerts,
      activeTab: activeTab,
      euiTheme: euiTheme
    })
  }] : []), {
    id: _types.CASE_VIEW_PAGE_TABS.FILES,
    name: _translations.FILES_TAB,
    badge: /*#__PURE__*/_react.default.createElement(FilesBadge, {
      isLoading: isLoadingFiles,
      fileStatsData: fileStatsData,
      activeTab: activeTab,
      euiTheme: euiTheme
    })
  }, ...(canShowObservableTabs ? [{
    id: _types.CASE_VIEW_PAGE_TABS.OBSERVABLES,
    name: _translations.OBSERVABLES_TAB,
    badge: /*#__PURE__*/_react.default.createElement(ObservablesBadge, {
      isLoading: isLoadingObservables,
      count: observables.length,
      activeTab: activeTab,
      euiTheme: euiTheme
    })
  }, {
    id: _types.CASE_VIEW_PAGE_TABS.SIMILAR_CASES,
    name: _translations.SIMILAR_CASES_TAB,
    badge: /*#__PURE__*/_react.default.createElement(SimilarCasesBadge, {
      activeTab: activeTab,
      euiTheme: euiTheme,
      count: similarCasesData === null || similarCasesData === void 0 ? void 0 : similarCasesData.total
    })
  }] : [])], [features.alerts.enabled, features.alerts.isExperimental, caseData.totalAlerts, activeTab, euiTheme, isLoadingFiles, fileStatsData, canShowObservableTabs, isLoadingObservables, observables.length, similarCasesData === null || similarCasesData === void 0 ? void 0 : similarCasesData.total]);
  const renderTabs = (0, _react.useCallback)(() => {
    return tabs.map((tab, index) => {
      var _tab$badge;
      return /*#__PURE__*/_react.default.createElement(_eui.EuiTab, {
        "data-test-subj": `case-view-tab-title-${tab.id}`,
        key: index,
        onClick: () => navigateToCaseView({
          detailName: caseData.id,
          tabId: tab.id
        }),
        isSelected: tab.id === activeTab
      }, /*#__PURE__*/_react.default.createElement(TabTitle, {
        title: tab.name
      }), (_tab$badge = tab.badge) !== null && _tab$badge !== void 0 ? _tab$badge : null);
    });
  }, [activeTab, caseData.id, navigateToCaseView, tabs]);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiTabs, {
    "data-test-subj": "case-view-tabs"
  }, renderTabs()), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "l"
  }));
});
CaseViewTabs.displayName = 'CaseViewTabs';