"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getCasesByAlertIdRoute = void 0;
var _configSchema = require("@kbn/config-schema");
var _constants = require("../../../../../common/constants");
var _error = require("../../../../common/error");
var _create_cases_route = require("../../create_cases_route");
var _constants2 = require("../../constants");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const getCasesByAlertIdRoute = exports.getCasesByAlertIdRoute = (0, _create_cases_route.createCasesRoute)({
  method: 'get',
  path: _constants.CASE_ALERTS_URL,
  security: _constants2.DEFAULT_CASES_ROUTE_SECURITY,
  params: {
    params: _configSchema.schema.object({
      alert_id: _configSchema.schema.string({
        minLength: 1
      })
    })
  },
  routerOptions: {
    access: 'public',
    summary: `Get cases for an alert`,
    tags: ['oas-tag:cases']
  },
  handler: async ({
    context,
    request,
    response
  }) => {
    try {
      const alertID = request.params.alert_id;
      const caseContext = await context.cases;
      const casesClient = await caseContext.getCasesClient();
      const options = request.query;
      const res = await casesClient.cases.getCasesByAlertID({
        alertID,
        options
      });
      return response.ok({
        body: res
      });
    } catch (error) {
      throw (0, _error.createCaseError)({
        message: `Failed to retrieve case ids for this alert id: ${request.params.alert_id}: ${error}`,
        error
      });
    }
  }
});