"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.findUserActionsRoute = void 0;
var _configSchema = require("@kbn/config-schema");
var _user_actions = require("../../../../common/utils/user_actions");
var _constants = require("../../../../common/constants");
var _error = require("../../../common/error");
var _create_cases_route = require("../create_cases_route");
var _constants2 = require("../constants");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const params = {
  params: _configSchema.schema.object({
    case_id: _configSchema.schema.string()
  })
};
const findUserActionsRoute = exports.findUserActionsRoute = (0, _create_cases_route.createCasesRoute)({
  method: 'get',
  path: _constants.INTERNAL_CASE_FIND_USER_ACTIONS_URL,
  security: _constants2.DEFAULT_CASES_ROUTE_SECURITY,
  params,
  routerOptions: {
    access: 'internal'
  },
  handler: async ({
    context,
    request,
    response
  }) => {
    try {
      const caseContext = await context.cases;
      const casesClient = await caseContext.getCasesClient();
      const caseId = request.params.case_id;
      const options = request.query;
      const userActionsResponse = await casesClient.userActions.find({
        caseId,
        params: options
      });
      const uniqueCommentIds = new Set();
      for (const action of userActionsResponse.userActions) {
        if ((0, _user_actions.isCommentUserAction)(action) && action.comment_id) {
          uniqueCommentIds.add(action.comment_id);
        }
      }
      const commentIds = Array.from(uniqueCommentIds);
      let attachmentRes = {
        attachments: [],
        errors: []
      };
      if (commentIds.length > 0) {
        attachmentRes = await casesClient.attachments.bulkGet({
          caseID: caseId,
          attachmentIDs: commentIds
        });
      }
      const res = {
        ...userActionsResponse,
        latestAttachments: attachmentRes.attachments
      };
      return response.ok({
        body: res
      });
    } catch (error) {
      throw (0, _error.createCaseError)({
        message: `Failed to retrieve case details in route case id: ${request.params.case_id}: \n${error}`,
        error
      });
    }
  }
});