"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.registerRoutes = registerRoutes;
var _get = require("./get");
var _resolve = require("./resolve");
var _create = require("./create");
var _delete = require("./delete");
var _find = require("./find");
var _update = require("./update");
var _bulk_get = require("./bulk_get");
var _bulk_create = require("./bulk_create");
var _bulk_update = require("./bulk_update");
var _bulk_delete = require("./bulk_delete");
var _export = require("./export");
var _import = require("./import");
var _resolve_import_errors = require("./resolve_import_errors");
var _migrate = require("./migrate");
var _bulk_resolve = require("./bulk_resolve");
var _deprecations = require("./deprecations");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

function registerRoutes({
  http,
  coreUsageData,
  logger,
  config,
  migratorPromise,
  kibanaVersion,
  kibanaIndex,
  isServerless,
  docLinks
}) {
  const router = http.createRouter('/api/saved_objects/');
  const internalOnServerless = isServerless ? 'internal' : 'public';
  const deprecationInfo = {
    documentationUrl: `${docLinks.links.management.savedObjectsApiList}`,
    severity: 'warning',
    // will not break deployment upon upgrade
    reason: {
      type: 'deprecate'
    }
  };
  (0, _get.registerGetRoute)(router, {
    config,
    coreUsageData,
    logger,
    access: internalOnServerless,
    deprecationInfo
  });
  (0, _resolve.registerResolveRoute)(router, {
    config,
    coreUsageData,
    logger,
    access: internalOnServerless,
    deprecationInfo
  });
  (0, _create.registerCreateRoute)(router, {
    config,
    coreUsageData,
    logger,
    access: internalOnServerless,
    deprecationInfo
  });
  (0, _delete.registerDeleteRoute)(router, {
    config,
    coreUsageData,
    logger,
    access: internalOnServerless,
    deprecationInfo
  });
  (0, _find.registerFindRoute)(router, {
    config,
    coreUsageData,
    logger,
    access: internalOnServerless,
    deprecationInfo
  });
  (0, _update.registerUpdateRoute)(router, {
    config,
    coreUsageData,
    logger,
    access: internalOnServerless,
    deprecationInfo
  });
  (0, _bulk_get.registerBulkGetRoute)(router, {
    config,
    coreUsageData,
    logger,
    access: internalOnServerless,
    deprecationInfo
  });
  (0, _bulk_create.registerBulkCreateRoute)(router, {
    config,
    coreUsageData,
    logger,
    access: internalOnServerless,
    deprecationInfo
  });
  (0, _bulk_resolve.registerBulkResolveRoute)(router, {
    config,
    coreUsageData,
    logger,
    access: internalOnServerless,
    deprecationInfo
  });
  (0, _bulk_update.registerBulkUpdateRoute)(router, {
    config,
    coreUsageData,
    logger,
    access: internalOnServerless,
    deprecationInfo
  });
  (0, _bulk_delete.registerBulkDeleteRoute)(router, {
    config,
    coreUsageData,
    logger,
    access: internalOnServerless,
    deprecationInfo
  });
  (0, _export.registerExportRoute)(router, {
    config,
    coreUsageData
  });
  (0, _import.registerImportRoute)(router, {
    config,
    coreUsageData
  });
  (0, _resolve_import_errors.registerResolveImportErrorsRoute)(router, {
    config,
    coreUsageData
  });
  const internalRouter = http.createRouter('/internal/saved_objects/');
  (0, _migrate.registerMigrateRoute)(internalRouter, migratorPromise);
  (0, _deprecations.registerDeleteUnknownTypesRoute)(internalRouter, {
    kibanaIndex,
    kibanaVersion
  });
}