"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.UiSettingsClient = void 0;
var _lodash = require("lodash");
var _ui_settings_client_common = require("./ui_settings_client_common");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

class UiSettingsClient extends _ui_settings_client_common.UiSettingsClientCommon {
  constructor(params) {
    super(params);
  }
  async update(key, newVal) {
    this.assertUpdateAllowed(key);
    const declared = this.isDeclared(key);
    const defaults = this.defaults;
    const oldVal = declared ? this.cache[key].userValue : undefined;
    const unchanged = oldVal === newVal;
    if (unchanged) {
      return true;
    }
    const initialVal = declared ? this.get(key) : undefined;
    this.setLocally(key, newVal);
    try {
      const {
        settings
      } = await this.api.batchSet(key, newVal);
      this.cache = (0, _lodash.defaultsDeep)({}, defaults, settings);
      return true;
    } catch (error) {
      this.setLocally(key, initialVal);
      this.updateErrors$.next(error);
      return false;
    }
  }
}
exports.UiSettingsClient = UiSettingsClient;