"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.IndexInput = void 0;
var _eui = require("@elastic/eui");
var _react = _interopRequireWildcard(require("react"));
var _useDebounce = _interopRequireDefault(require("react-use/lib/useDebounce"));
var _i18n = require("@kbn/i18n");
var _useMountedState = _interopRequireDefault(require("react-use/lib/useMountedState"));
var _i18nReact = require("@kbn/i18n-react");
var _file_manager = require("./file_manager/file_manager");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const IndexInput = ({
  setIndexName,
  setIndexValidationStatus,
  fileUpload
}) => {
  const [indexNameLocal, setIndexNameLocal] = (0, _react.useState)('');
  const [indexNameError, setIndexNameError] = (0, _react.useState)('');
  const isMounted = (0, _useMountedState.default)();
  (0, _useDebounce.default)(async () => {
    setIndexValidationStatus(_file_manager.STATUS.STARTED);
    if (indexNameLocal === '') {
      setIndexValidationStatus(_file_manager.STATUS.COMPLETED);
      setIndexNameError('');
      setIndexName('');
      return;
    }
    const exists = await fileUpload.checkIndexExists(indexNameLocal);
    const error = exists ? _i18n.i18n.translate('xpack.dataVisualizer.file.importView.indexNameAlreadyExistsErrorMessage', {
      defaultMessage: 'Index name already exists'
    }) : isIndexNameValid(indexNameLocal);
    if (!isMounted()) {
      return;
    }
    setIndexName(indexNameLocal);
    setIndexNameError(error);
    setIndexValidationStatus(error === '' ? _file_manager.STATUS.COMPLETED : _file_manager.STATUS.FAILED);
  }, 250, [indexNameLocal]);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, {
    size: "s"
  }, /*#__PURE__*/_react.default.createElement("h3", null, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.dataVisualizer.file.importView.createIndexTitle",
    defaultMessage: "Create new index"
  }))), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "xs"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiFormRow, {
    label: _i18n.i18n.translate('xpack.dataVisualizer.file.importView.indexNameLabel', {
      defaultMessage: 'Index name'
    }),
    isInvalid: indexNameError !== '',
    error: indexNameError,
    fullWidth: true,
    helpText: _i18n.i18n.translate('xpack.dataVisualizer.file.importView.indexNameContainsIllegalCharactersErrorMessage', {
      defaultMessage: 'Index names must be lowercase and can only contain hyphens and numbers.'
    })
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFieldText, {
    fullWidth: true,
    value: indexNameLocal,
    onChange: e => setIndexNameLocal(e.target.value),
    placeholder: _i18n.i18n.translate('xpack.dataVisualizer.file.importView.indexNameContainsIllegalCharactersErrorMessage', {
      defaultMessage: 'Add name to index'
    })
  })));
};
exports.IndexInput = IndexInput;
function isIndexNameValid(name) {
  const reg = new RegExp('[\\\\/*?"<>|\\s,#]+');
  if (name !== name.toLowerCase() ||
  // name should be lowercase
  name === '.' || name === '..' ||
  // name can't be . or ..
  name.match(/^[-_+]/) !== null ||
  // name can't start with these chars
  name.match(reg) !== null // name can't contain these chars
  ) {
    return _i18n.i18n.translate('xpack.dataVisualizer.file.importView.indexNameContainsIllegalCharactersErrorMessage', {
      defaultMessage: 'Index name contains illegal characters'
    });
  }
  return '';
}