"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useDefaultAdHocDataViews = void 0;
var _react = require("react");
var _useLatest = _interopRequireDefault(require("react-use/lib/useLatest"));
var _useUnmount = _interopRequireDefault(require("react-use/lib/useUnmount"));
var _use_discover_services = require("../../hooks/use_discover_services");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

/**
 * Hook to retrieve and initialize the default profile ad hoc data views
 * @param Options The options object
 * @returns An object containing the initialization function
 */
const useDefaultAdHocDataViews = ({
  stateContainer,
  rootProfileState
}) => {
  const {
    dataViews
  } = (0, _use_discover_services.useDiscoverServices)();
  const {
    internalState
  } = stateContainer;
  const initializeDataViews = (0, _useLatest.default)(async () => {
    if (rootProfileState.rootProfileLoading) {
      return;
    }

    // Clear the cache of old data views before creating
    // the new ones to avoid cache hits on duplicate IDs
    for (const prevId of internalState.get().defaultProfileAdHocDataViewIds) {
      dataViews.clearInstanceCache(prevId);
    }
    const profileDataViewSpecs = rootProfileState.getDefaultAdHocDataViews();
    const profileDataViews = await Promise.all(profileDataViewSpecs.map(spec => dataViews.create(spec, true)));
    internalState.transitions.setDefaultProfileAdHocDataViews(profileDataViews);
  });

  // This approach allows us to return a callback with a stable reference
  const [initializeProfileDataViews] = (0, _react.useState)(() => () => initializeDataViews.current());

  // Make sure to clean up on unmount
  (0, _useUnmount.default)(() => {
    for (const prevId of internalState.get().defaultProfileAdHocDataViewIds) {
      dataViews.clearInstanceCache(prevId);
    }
    internalState.transitions.setDefaultProfileAdHocDataViews([]);
  });
  return {
    initializeProfileDataViews
  };
};
exports.useDefaultAdHocDataViews = useDefaultAdHocDataViews;