"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getAgentName = getAgentName;
exports.hasOpenTelemetryPrefix = hasOpenTelemetryPrefix;
exports.isAWSLambdaAgentName = isAWSLambdaAgentName;
exports.isAndroidAgentName = isAndroidAgentName;
exports.isAzureFunctionsAgentName = isAzureFunctionsAgentName;
exports.isElasticAgentName = void 0;
exports.isIosAgentName = isIosAgentName;
exports.isJRubyAgentName = isJRubyAgentName;
exports.isJavaAgentName = isJavaAgentName;
exports.isMobileAgentName = isMobileAgentName;
exports.isOpenTelemetryAgentName = isOpenTelemetryAgentName;
exports.isRumAgentName = isRumAgentName;
exports.isRumOrMobileAgentName = isRumOrMobileAgentName;
exports.isServerlessAgentName = isServerlessAgentName;
var _agent_names = require("./agent_names");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

const ElasticAgentNamesSet = new Set(_agent_names.ELASTIC_AGENT_NAMES);
function getAgentName(agentName, telemetryAgentName, telemetrySdkName) {
  if (agentName) {
    return agentName;
  }
  if (telemetrySdkName && telemetryAgentName) {
    return `${telemetrySdkName}/${telemetryAgentName}`;
  }
  return telemetryAgentName;
}
function hasOpenTelemetryPrefix(agentName, language = '') {
  if (!agentName) {
    return false;
  }
  return agentName.startsWith(`opentelemetry/${language}`) || agentName.startsWith(`otlp/${language}`);
}
function isOpenTelemetryAgentName(agentName) {
  return hasOpenTelemetryPrefix(agentName) || _agent_names.OPEN_TELEMETRY_AGENT_NAMES.includes(agentName);
}
const isElasticAgentName = agentName => ElasticAgentNamesSet.has(agentName);
exports.isElasticAgentName = isElasticAgentName;
function isJavaAgentName(agentName) {
  return hasOpenTelemetryPrefix(agentName, 'java') || _agent_names.JAVA_AGENT_NAMES.includes(agentName);
}
function isRumAgentName(agentName) {
  return hasOpenTelemetryPrefix(agentName, 'webjs') || _agent_names.RUM_AGENT_NAMES.includes(agentName);
}
function isMobileAgentName(agentName) {
  return isIosAgentName(agentName) || isAndroidAgentName(agentName);
}
function isRumOrMobileAgentName(agentName) {
  return isRumAgentName(agentName) || isMobileAgentName(agentName);
}
function isIosAgentName(agentName) {
  const lowercasedAgentName = agentName && agentName.toLowerCase();
  return hasOpenTelemetryPrefix(lowercasedAgentName, 'swift') || _agent_names.IOS_AGENT_NAMES.includes(lowercasedAgentName);
}
function isAndroidAgentName(agentName) {
  const lowercasedAgentName = agentName && agentName.toLowerCase();
  return hasOpenTelemetryPrefix(lowercasedAgentName, 'android') || _agent_names.ANDROID_AGENT_NAMES.includes(lowercasedAgentName);
}
function isJRubyAgentName(agentName, runtimeName) {
  return agentName === 'ruby' && (runtimeName === null || runtimeName === void 0 ? void 0 : runtimeName.toLowerCase()) === 'jruby';
}
function isServerlessAgentName(serverlessType) {
  return isAWSLambdaAgentName(serverlessType) || isAzureFunctionsAgentName(serverlessType);
}
function isAWSLambdaAgentName(serverlessType) {
  return serverlessType === 'aws.lambda';
}
function isAzureFunctionsAgentName(serverlessType) {
  return serverlessType === 'azure.functions';
}