"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getDefendInsightRoute = void 0;
var _common = require("@kbn/elastic-assistant-common/impl/schemas/common");
var _elasticAssistantCommon = require("@kbn/elastic-assistant-common");
var _securitysolutionEsUtils = require("@kbn/securitysolution-es-utils");
var _build_response = require("../../lib/build_response");
var _helpers = require("./helpers");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const getDefendInsightRoute = router => {
  router.versioned.get({
    access: 'internal',
    path: _elasticAssistantCommon.DEFEND_INSIGHTS_BY_ID,
    security: {
      authz: {
        requiredPrivileges: ['securitySolution-readWorkflowInsights']
      }
    }
  }).addVersion({
    version: _elasticAssistantCommon.API_VERSIONS.internal.v1,
    validate: {
      request: {
        params: (0, _common.buildRouteValidationWithZod)(_elasticAssistantCommon.DefendInsightGetRequestParams)
      },
      response: {
        200: {
          body: {
            custom: (0, _common.buildRouteValidationWithZod)(_elasticAssistantCommon.DefendInsightGetResponse)
          }
        }
      }
    }
  }, async (context, request, response) => {
    const resp = (0, _build_response.buildResponse)(response);
    const ctx = await context.resolve(['licensing', 'elasticAssistant']);
    const assistantContext = ctx.elasticAssistant;
    const logger = assistantContext.logger;
    try {
      const isEnabled = (0, _helpers.isDefendInsightsEnabled)({
        request,
        logger,
        assistantContext
      });
      if (!isEnabled) {
        return response.notFound();
      }
      if (!ctx.licensing.license.hasAtLeast('enterprise')) {
        return response.forbidden({
          body: {
            message: 'Your license does not support Defend Workflows. Please upgrade your license.'
          }
        });
      }
      const dataClient = await assistantContext.getDefendInsightsDataClient();
      const authenticatedUser = await assistantContext.getCurrentUser();
      if (authenticatedUser == null) {
        return resp.error({
          body: `Authenticated user not found`,
          statusCode: 401
        });
      }
      if (!dataClient) {
        return resp.error({
          body: `Defend insights data client not initialized`,
          statusCode: 500
        });
      }
      const defendInsight = await (0, _helpers.updateDefendInsightLastViewedAt)({
        dataClient,
        id: request.params.id,
        authenticatedUser
      });
      return response.ok({
        body: {
          data: defendInsight
        }
      });
    } catch (err) {
      logger.error(err);
      const error = (0, _securitysolutionEsUtils.transformError)(err);
      return resp.error({
        body: {
          success: false,
          error: error.message
        },
        statusCode: error.statusCode
      });
    }
  });
};
exports.getDefendInsightRoute = getDefendInsightRoute;