"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.joinIndicesToSuggestions = exports.getPosition = void 0;
var _i18n = require("@kbn/i18n");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

const REGEX = /^(?<type>\w+((?<after_type>\s+((?<mnemonic>(JOIN|JOI|JO|J)((?<after_mnemonic>\s+((?<index>\S+((?<after_index>\s+(?<as>(AS|A))?(?<after_as>\s+(((?<alias>\S+)?(?<after_alias>\s+)?)?))?((?<on>(ON|O)((?<after_on>\s+(?<cond>[^\s])?)?))?))?))?))?))?))?))?/i;
const positions = ['cond', 'after_on', 'on', 'after_alias', 'alias', 'after_as', 'as', 'after_index', 'index', 'after_mnemonic', 'mnemonic', 'after_type', 'type'];

/**
 * Returns the static position, or `cond` if the caret is in the `<conditions>`
 * part of the command, in which case further parsing is needed.
 */
const getStaticPosition = text => {
  const match = text.match(REGEX);
  if (!match || !match.groups) {
    return 'none';
  }
  let pos = 'cond';
  for (const position of positions) {
    if (match.groups[position]) {
      pos = position;
      break;
    }
  }
  return pos;
};
const getPosition = (text, command) => {
  const pos0 = getStaticPosition(text);
  const pos = pos0 === 'cond' ? 'condition' : pos0;
  return {
    pos,
    type: ''
  };
};
exports.getPosition = getPosition;
const joinIndicesToSuggestions = indices => {
  const mainSuggestions = [];
  const aliasSuggestions = [];
  for (const index of indices) {
    mainSuggestions.push({
      label: index.name,
      text: index.name + ' ',
      kind: 'Issue',
      detail: _i18n.i18n.translate('kbn-esql-validation-autocomplete.esql.autocomplete.join.indexType.index', {
        defaultMessage: 'Index'
      }),
      sortText: '0-INDEX-' + index.name
    });
    if (index.aliases) {
      for (const alias of index.aliases) {
        aliasSuggestions.push({
          label: alias,
          text: alias + ' $0',
          kind: 'Issue',
          detail: _i18n.i18n.translate('kbn-esql-validation-autocomplete.esql.autocomplete.join.indexType.alias', {
            defaultMessage: 'Alias'
          }),
          sortText: '1-ALIAS-' + alias
        });
      }
    }
  }
  return [...mainSuggestions, ...aliasSuggestions];
};
exports.joinIndicesToSuggestions = joinIndicesToSuggestions;