"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ManageAutoUpgradeAgentsModal = void 0;
var _react = _interopRequireWildcard(require("react"));
var _eui = require("@elastic/eui");
var _i18n = require("@kbn/i18n");
var _i18nReact = require("@kbn/i18n-react");
var _hooks = require("../../../../../../hooks");
var _services = require("../../../../../../../common/services");
var _agent_policy = require("../../../../../../hooks/use_request/agent_policy");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const ManageAutoUpgradeAgentsModal = ({
  onClose,
  agentPolicy,
  agentCount
}) => {
  const [isLoading, setIsLoading] = (0, _react.useState)(false);
  const {
    notifications
  } = (0, _hooks.useStartServices)();
  const [targetVersions, setTargetVersions] = (0, _react.useState)(agentPolicy.required_versions || []);
  const {
    data: agentsAvailableVersions
  } = (0, _hooks.useGetAgentsAvailableVersionsQuery)({
    enabled: true
  });
  const latestVersion = agentsAvailableVersions === null || agentsAvailableVersions === void 0 ? void 0 : agentsAvailableVersions.items[0];
  const [errors, setErrors] = (0, _react.useState)([]);
  const submitUpdateAgentPolicy = async () => {
    setIsLoading(true);
    let isSuccess = false;
    try {
      await (0, _agent_policy.sendUpdateAgentPolicyForRq)(agentPolicy.id, {
        name: agentPolicy.name,
        namespace: agentPolicy.namespace,
        required_versions: targetVersions
      });
      notifications.toasts.addSuccess(_i18n.i18n.translate('xpack.fleet.manageAutoUpgradeAgents.successNotificationTitle', {
        defaultMessage: "Successfully updated ''{name}'' auto-upgrade agents settings",
        values: {
          name: agentPolicy.name
        }
      }));
      isSuccess = true;
    } catch (e) {
      notifications.toasts.addDanger(_i18n.i18n.translate('xpack.fleet.manageAutoUpgradeAgents.errorNotificationTitle', {
        defaultMessage: 'Unable to update agent policy'
      }));
    }
    setIsLoading(false);
    onClose(isSuccess);
  };
  async function onSubmit() {
    await submitUpdateAgentPolicy();
  }
  async function updateTargetVersions(newVersions) {
    const error = (0, _services.checkTargetVersionsValidity)(newVersions);
    setErrors(error ? [error] : []);
    setTargetVersions(newVersions);
  }
  return /*#__PURE__*/_react.default.createElement(_eui.EuiConfirmModal, {
    "data-test-subj": "manageAutoUpgradeAgentsModal",
    title: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.fleet.manageAutoUpgradeAgents.modalTitle",
      defaultMessage: "Manage auto-upgrade agents"
    }),
    onCancel: () => onClose(false),
    onConfirm: onSubmit,
    confirmButtonDisabled: isLoading || errors.length > 0,
    cancelButtonText: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.fleet.manageAutoUpgradeAgents.cancelButtonLabel",
      defaultMessage: "Cancel"
    }),
    confirmButtonText: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.fleet.manageAutoUpgradeAgents.saveButtonLabel",
      defaultMessage: "Save"
    }),
    style: {
      width: 1000
    }
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    direction: "column"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, agentCount > 0 ? /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiCallOut, {
    iconType: "iInCircle",
    title: _i18n.i18n.translate('xpack.fleet.manageAutoUpgradeAgents.calloutTitle', {
      defaultMessage: 'This action will update {agentCount, plural, one {# agent} other {# agents}}',
      values: {
        agentCount
      }
    })
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "m"
  })) : null, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.fleet.manageAutoUpgradeAgents.descriptionText",
    defaultMessage: "Add the target agent version for automatic upgrades."
  })), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiForm, {
    isInvalid: errors.length > 0,
    error: errors,
    component: "form"
  }, targetVersions.map((requiredVersion, index) => /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(TargetVersionsRow, {
    agentsAvailableVersions: (agentsAvailableVersions === null || agentsAvailableVersions === void 0 ? void 0 : agentsAvailableVersions.items) || [],
    requiredVersion: requiredVersion,
    key: index,
    onRemove: () => {
      updateTargetVersions(targetVersions.filter((_, i) => i !== index));
    },
    onUpdate: (version, percentage) => {
      updateTargetVersions(targetVersions.map((targetVersion, i) => i === index ? {
        version,
        percentage
      } : targetVersion));
    }
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "s"
  }))))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFormRow, null, /*#__PURE__*/_react.default.createElement(_eui.EuiButtonEmpty, {
    onClick: () => {
      updateTargetVersions([...targetVersions, {
        version: latestVersion || '',
        percentage: targetVersions.length === 0 ? 100 : 1
      }]);
    },
    iconType: "plusInCircle"
  }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.fleet.manageAutoUpgradeAgents.addVersionButton",
    defaultMessage: "Add target version"
  }))))));
};
exports.ManageAutoUpgradeAgentsModal = ManageAutoUpgradeAgentsModal;
const TargetVersionsRow = ({
  agentsAvailableVersions,
  requiredVersion,
  onRemove,
  onUpdate
}) => {
  const options = agentsAvailableVersions.map(version => ({
    value: version,
    inputDisplay: version
  }));
  const [version, setVersion] = (0, _react.useState)(requiredVersion.version);
  const onVersionChange = value => {
    setVersion(value);
  };
  const [percentage, setPercentage] = (0, _react.useState)(requiredVersion.percentage);
  const onPercentageChange = value => {
    setPercentage(value);
  };
  return /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    direction: "row",
    alignItems: "flexEnd"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFormRow, {
    label: /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.fleet.manageAutoUpgradeAgents.targetAgentVersionTitle",
      defaultMessage: "Target agent version"
    }), /*#__PURE__*/_react.default.createElement(_eui.EuiIconTip, {
      type: "iInCircle",
      content: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
        "data-test-subj": "targetVersionTooltip",
        id: "xpack.fleet.manageAutoUpgradeAgents.targetVersionTooltip",
        defaultMessage: "You can only downgrade agents manually."
      })
    }))
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiSuperSelect, {
    options: options,
    valueOfSelected: version,
    onChange: value => {
      onVersionChange(value);
      onUpdate(value, percentage);
    }
  }))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFormRow, {
    label: /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.fleet.manageAutoUpgradeAgents.percentageTitle",
      defaultMessage: "% of agents to upgrade"
    }), /*#__PURE__*/_react.default.createElement(_eui.EuiIconTip, {
      type: "iInCircle",
      content: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
        "data-test-subj": "percentageTooltip",
        id: "xpack.fleet.manageAutoUpgradeAgents.percentageTooltip",
        defaultMessage: "Set 100 to upgrade all agents in the policy."
      })
    }))
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFieldNumber, {
    value: percentage,
    onChange: e => {
      const newValue = parseInt(e.target.value, 10);
      onPercentageChange(newValue);
      onUpdate(version, newValue);
    },
    min: 0,
    step: 1,
    max: 100,
    required: true
  }))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFormRow, {
    label: ""
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiButton, {
    onClick: onRemove,
    color: "text"
  }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.fleet.manageAutoUpgradeAgents.removeVersionButton",
    defaultMessage: "Remove"
  })))));
};