"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AgentlessStepConfirmEnrollment = void 0;
var _react = _interopRequireWildcard(require("react"));
var _i18n = require("@kbn/i18n");
var _i18nReact = require("@kbn/i18n-react");
var _eui = require("@elastic/eui");
var _hooks = require("../../hooks");
var _agent_details_integrations = require("../../applications/fleet/sections/agents/agent_details_page/components/agent_details/agent_details_integrations");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const AgentlessStepConfirmEnrollment = ({
  agent,
  agentPolicy,
  integrationTitle
}) => {
  const {
    docLinks
  } = (0, _hooks.useStartServices)();
  const [overallState, setOverallState] = (0, _react.useState)('pending');

  // Calculate overall UI state from agent status
  (0, _react.useEffect)(() => {
    if (agent && agent.status === 'online') {
      setOverallState('success');
    } else if (agent && (agent.status === 'error' || agent.status === 'degraded')) {
      setOverallState('failure');
    } else {
      setOverallState('pending');
    }
  }, [agent]);
  if (overallState === 'success') {
    return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiCallOut, {
      color: "success",
      title: _i18n.i18n.translate('xpack.fleet.agentlessEnrollmentFlyout.confirmEnrollment.successText', {
        defaultMessage: 'Agentless deployment was successful'
      }),
      iconType: "check"
    }), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
      size: "m"
    }), /*#__PURE__*/_react.default.createElement(_eui.EuiText, null, /*#__PURE__*/_react.default.createElement("p", null, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.fleet.agentlessEnrollmentFlyout.confirmEnrollment.successHelperText",
      defaultMessage: "{integrationTitle} agentless integration has been successfully established. You can now seamlessly monitor and manage your {integrationTitle} resources without the need for any additional agents.",
      values: {
        integrationTitle
      }
    }))));
  } else if (overallState === 'failure') {
    return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiCallOut, {
      color: "danger",
      title: _i18n.i18n.translate('xpack.fleet.agentlessEnrollmentFlyout.confirmEnrollment.failureText', {
        defaultMessage: 'Agentless deployment failed'
      }),
      iconType: "warning"
    }, (agent === null || agent === void 0 ? void 0 : agent.last_checkin_message) && /*#__PURE__*/_react.default.createElement("p", null, agent.last_checkin_message)), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
      size: "m"
    }), /*#__PURE__*/_react.default.createElement(_eui.EuiText, null, /*#__PURE__*/_react.default.createElement("p", null, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.fleet.agentlessEnrollmentFlyout.confirmEnrollment.failureHelperText",
      defaultMessage: "{integrationTitle} agentless integration failed to establish. Check out the {troubleshootingGuideLink} for help.",
      values: {
        integrationTitle,
        troubleshootingGuideLink: /*#__PURE__*/_react.default.createElement(_eui.EuiLink, {
          href: docLinks.links.fleet.troubleshooting,
          target: "_blank"
        }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
          id: "xpack.fleet.agentlessEnrollmentFlyout.confirmEnrollment.pendingHelperText.troubleshootingLinkLabel",
          defaultMessage: "troubleshooting guide"
        }))
      }
    }))), agent && agentPolicy && /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
      size: "m"
    }), /*#__PURE__*/_react.default.createElement(_agent_details_integrations.AgentDetailsIntegrations, {
      agent: agent,
      agentPolicy: agentPolicy,
      linkToLogs: false
    })));
  }
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiPanel, {
    color: "subdued",
    paddingSize: "xl",
    className: "eui-textCenter"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiButton, {
    disabled: true,
    size: "s",
    isLoading: true
  }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.fleet.agentlessEnrollmentFlyout.confirmEnrollment.pendingText",
    defaultMessage: "Listening for agentless connection... this could take several minutes"
  }))), /*#__PURE__*/_react.default.createElement(_eui.EuiSpacer, {
    size: "m"
  }), /*#__PURE__*/_react.default.createElement(_eui.EuiText, null, /*#__PURE__*/_react.default.createElement("p", null, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.fleet.agentlessEnrollmentFlyout.confirmEnrollment.pendingHelperText",
    defaultMessage: "Getting ready to connect with your cloud account and confirm incoming data. If you're having trouble connecting, check out the {troubleshootingGuideLink}. You can track the latest status from {policyPagePath} Status column.",
    values: {
      troubleshootingGuideLink: /*#__PURE__*/_react.default.createElement(_eui.EuiLink, {
        href: docLinks.links.fleet.troubleshooting,
        target: "_blank"
      }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
        id: "xpack.fleet.agentlessEnrollmentFlyout.confirmEnrollment.pendingHelperText.troubleshootingLinkLabel",
        defaultMessage: "troubleshooting guide"
      })),
      policyPagePath: /*#__PURE__*/_react.default.createElement("strong", null, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
        id: "xpack.fleet.agentlessEnrollmentFlyout.confirmEnrollment.pendingHelperText.policyPagePath",
        defaultMessage: "Integration policies \u2192 Agentless Integrations"
      }))
    }
  }))));
};
exports.AgentlessStepConfirmEnrollment = AgentlessStepConfirmEnrollment;