"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getConnectorById = void 0;
var _inferenceCommon = require("@kbn/inference-common");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/**
 * Retrieves a connector given the provided `connectorId` and asserts it's an inference connector
 */
const getConnectorById = async ({
  connectorId,
  actionsClient
}) => {
  var _connector$config;
  let connector;
  try {
    connector = await actionsClient.get({
      id: connectorId,
      throwIfSystemAction: true
    });
  } catch (error) {
    throw (0, _inferenceCommon.createInferenceRequestError)(`No connector found for id '${connectorId}'`, 400);
  }
  if (!(0, _inferenceCommon.isSupportedConnector)(connector)) {
    throw (0, _inferenceCommon.createInferenceRequestError)(`Connector '${connector.id}' of type '${connector.actionTypeId}' not recognized as a supported connector`, 400);
  }
  return {
    connectorId: connector.id,
    name: connector.name,
    type: connector.actionTypeId,
    config: (_connector$config = connector.config) !== null && _connector$config !== void 0 ? _connector$config : {}
  };
};
exports.getConnectorById = getConnectorById;