"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.IngestPipelinesPlugin = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _routes = require("./routes");
var _shared_imports = require("./shared_imports");
var _constants = require("../common/constants");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

class IngestPipelinesPlugin {
  constructor(initContext) {
    (0, _defineProperty2.default)(this, "apiRoutes", void 0);
    (0, _defineProperty2.default)(this, "config", void 0);
    this.apiRoutes = new _routes.ApiRoutes();
    this.config = initContext.config.get();
  }
  setup({
    http
  }, {
    security,
    features
  }) {
    const router = http.createRouter();
    features.registerElasticsearchFeature({
      id: 'ingest_pipelines',
      management: {
        ingest: ['ingest_pipelines']
      },
      privileges: [{
        ui: [],
        requiredClusterPrivileges: _constants.APP_CLUSTER_REQUIRED_PRIVILEGES
      }]
    });
    this.apiRoutes.setup({
      router,
      config: {
        isSecurityEnabled: () => security !== undefined && security.license.isEnabled(),
        enableManageProcessors: this.config.enableManageProcessors !== false
      },
      lib: {
        handleEsError: _shared_imports.handleEsError
      }
    });
  }
  start() {}
  stop() {}
}
exports.IngestPipelinesPlugin = IngestPipelinesPlugin;