"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.initializeIntegrations = initializeIntegrations;
var _esQuery = require("@kbn/es-query");
var _lodash = require("lodash");
var _helper = require("../helper");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function initializeIntegrations(getLatestState, {
  attributeService
}) {
  return {
    api: {
      /**
       * This API is used by the dashboard to serialize the panel state to save it into its saved object.
       * Make sure to remove the attributes when the panel is by reference.
       */
      serializeState: () => {
        const currentState = getLatestState();
        const cleanedState = attributeService.extractReferences(currentState);
        if (cleanedState.rawState.savedObjectId) {
          return {
            ...cleanedState,
            rawState: {
              ...cleanedState.rawState,
              attributes: undefined
            }
          };
        }
        return cleanedState;
      },
      // TODO: workout why we have this duplicated
      getFullAttributes: () => getLatestState().attributes,
      getSavedVis: () => getLatestState().attributes,
      isTextBasedLanguage: () => (0, _helper.isTextBasedLanguage)(getLatestState()),
      getTextBasedLanguage: () => {
        var _getLatestState$attri;
        const query = (_getLatestState$attri = getLatestState().attributes) === null || _getLatestState$attri === void 0 ? void 0 : _getLatestState$attri.state.query;
        if (!query || !(0, _esQuery.isOfAggregateQueryType)(query)) {
          return;
        }
        const language = (0, _esQuery.getAggregateQueryMode)(query);
        return (0, _esQuery.getLanguageDisplayName)(language).toUpperCase();
      }
    },
    comparators: {},
    serialize: _helper.emptySerializer,
    cleanup: _lodash.noop
  };
}