"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.openEditorFlyout = openEditorFlyout;
var _react = _interopRequireDefault(require("react"));
var _rxjs = require("rxjs");
var _uuid = require("uuid");
var _eui = require("@elastic/eui");
var _reactKibanaMount = require("@kbn/react-kibana-mount");
var _sharedUxUtility = require("@kbn/shared-ux-utility");
var _presentationContainers = require("@kbn/presentation-containers");
var _presentationPublishing = require("@kbn/presentation-publishing");
var _content_management = require("../content_management");
var _kibana_services = require("../services/kibana_services");
var _serialize_attributes = require("../lib/serialize_attributes");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; } /*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */
const LazyLinksEditor = /*#__PURE__*/_react.default.lazy(() => Promise.resolve().then(() => _interopRequireWildcard(require('../components/editor/links_editor'))));
const LinksEditor = (0, _sharedUxUtility.withSuspense)(LazyLinksEditor, /*#__PURE__*/_react.default.createElement(_eui.EuiPanel, {
  className: "eui-textCenter"
}, /*#__PURE__*/_react.default.createElement(_eui.EuiLoadingSpinner, {
  size: "l"
})));

/**
 * @throws in case user cancels
 */
async function openEditorFlyout({
  initialState,
  parentDashboard
}) {
  if (!initialState) {
    /**
     * When creating a new links panel, the tooltip from the "Add panel" popover interacts badly with the flyout
     * and can cause a "double opening" animation if the flyout opens before the tooltip has time to unmount; so,
     * when creating a new links panel, we need to slow down the process a little bit so that the tooltip has time
     * to disappear before we try to open the flyout.
     *
     * This does not apply to editing existing links panels, since there is no tooltip for this action.
     */
    await new Promise(resolve => setTimeout(resolve, 50));
  }
  const overlayTracker = parentDashboard && (0, _presentationContainers.tracksOverlays)(parentDashboard) ? parentDashboard : undefined;
  const parentDashboardId = parentDashboard && (0, _presentationPublishing.apiPublishesSavedObjectId)(parentDashboard) ? parentDashboard.savedObjectId$.value : undefined;
  return new Promise(resolve => {
    const flyoutId = `linksEditorFlyout-${(0, _uuid.v4)()}`;
    const closeEditorFlyout = editorFlyout => {
      if (overlayTracker) {
        overlayTracker.clearOverlays();
      } else {
        editorFlyout.close();
      }
    };

    /**
     * Close the flyout whenever the app changes - this handles cases for when the flyout is open outside of the
     * Dashboard app (`overlayTracker` is not available)
     */
    _kibana_services.coreServices.application.currentAppId$.pipe((0, _rxjs.skip)(1), (0, _rxjs.take)(1)).subscribe(() => {
      if (!overlayTracker) editorFlyout.close();
    });
    const onSaveToLibrary = async (newLinks, newLayout) => {
      const newState = {
        ...initialState,
        links: newLinks,
        layout: newLayout
      };
      if (initialState !== null && initialState !== void 0 && initialState.savedObjectId) {
        const {
          attributes,
          references
        } = (0, _serialize_attributes.serializeLinksAttributes)(newState);
        await _content_management.linksClient.update({
          id: initialState.savedObjectId,
          data: attributes,
          options: {
            references
          }
        });
        resolve(newState);
        closeEditorFlyout(editorFlyout);
      } else {
        const saveResult = await (0, _content_management.runSaveToLibrary)(newState);
        resolve(saveResult);
        // If saveResult is undefined, the user cancelled the save as modal and we should not close the flyout
        if (saveResult) closeEditorFlyout(editorFlyout);
      }
    };
    const onAddToDashboard = (newLinks, newLayout) => {
      const newState = {
        ...initialState,
        links: newLinks,
        layout: newLayout
      };
      resolve(newState);
      closeEditorFlyout(editorFlyout);
    };
    const onCancel = () => {
      resolve(undefined);
      closeEditorFlyout(editorFlyout);
    };
    const editorFlyout = _kibana_services.coreServices.overlays.openFlyout((0, _reactKibanaMount.toMountPoint)(/*#__PURE__*/_react.default.createElement(LinksEditor, {
      flyoutId: flyoutId,
      initialLinks: initialState === null || initialState === void 0 ? void 0 : initialState.links,
      initialLayout: initialState === null || initialState === void 0 ? void 0 : initialState.layout,
      onClose: onCancel,
      onSaveToLibrary: onSaveToLibrary,
      onAddToDashboard: onAddToDashboard,
      parentDashboardId: parentDashboardId,
      isByReference: Boolean(initialState === null || initialState === void 0 ? void 0 : initialState.savedObjectId)
    }), _kibana_services.coreServices), {
      id: flyoutId,
      maxWidth: 500,
      paddingSize: 'm',
      ownFocus: true,
      onClose: onCancel,
      outsideClickCloses: false,
      className: 'linksPanelEditor',
      'data-test-subj': 'links--panelEditor--flyout'
    });
    if (overlayTracker) {
      overlayTracker.openOverlay(editorFlyout);
    }
  });
}